"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = nestedApply;

var _ramda = require("ramda");

var _upTo = require("../upTo");

var _upTo2 = _interopRequireDefault(_upTo);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function nestedApply(applicator) {
  return function nestedApplyApplication(inner) {
    return function nestedApplyApplicationInitial(depth) {
      return (0, _ramda.reduce)(function (state) {
        return applicator(state);
      }, inner, (0, _upTo2.default)((0, _ramda.inc)(depth)));
    };
  };
} // > ? Function:a -> Function:b -> Number -> Function:ab
//
// Takes a function (the applicator) that takes function(s) (later referred to as
// the inner) and value(s) (`map()`, `forEach()`, `find()`), a function (the inner)
// that will be applied to a value(s), and finally a number (depth) to apply that
// applicator around the inner.
//
// In the below example we want to take two sets of records and index them by id:
//
// ``` javascript
// import {nestedApply} from "ramda-extra"
//
// const records = [
//   [
//     {
//       id: "a1",
//       type: "commercial",
//     },
//     {
//       id: "a2",
//       type: "commercial",
//     }
//   ],
//   [
//     {
//       id: "b1",
//       type: "residential",
//     },
//     {
//       id: "b2",
//       type: "residential",
//     }
//   ]
// ]
//
// // Normally we'd just do `map(map(indexBy(prop("id"))))`, however we can
// // make this easier and dynamic:
// nestedApply(map)(indexBy(prop("id")))(1)
// ```
//
// And the result
//
// ``` javascript
// [
//   {
//     a1: {
//       id: "a1",
//       type: "commercial",
//     },
//     a2: {
//       id: "a2",
//       type: "commercial",
//     },
//   },
//   {
//     b1: {
//       id: "b1",
//       type: "residential",
//     },
//     b2: {
//       id: "b2",
//       type: "residential",
//     },
//   },
// ]
// ```